/*
 * @Description: 通用低代码呈现页面主数据
 * @Author: Ben Lin
 * @version:
 * @Date: 2024-06-02 17:52:35
 * @LastEditors: Ben Lin
 * @LastEditTime: 2024-06-26 22:23:12
 */

import { ActionItem, BasicColumn, FormSchema } from '/@/components/Table';
import { useI18n } from '/@/hooks/web/useI18n';
import { isNullOrEmpty } from '/@/utils/is';
import { woCustFn, woformSchema } from '/@/views/components/bizMesWo';
import { useModal } from '/@/components/Modal';

const { t } = useI18n();
/**
 * @description: 低代码页面获取操作字段结构Json，如增加按钮及方法
 * 攻略:
 *  1. 另新建驼峰实体名.ts的文件，如：BAS_REASON.ts。以便区别不同页面的方法
 *  2. 替换主页面编辑按钮方法变为跳转到高级页面，方法中传入 { CODE: 主表记录的关键字段值，一般是XXX_CODE的值, ID: 当前记录的ID, Name: 'BAS_DEFECT'（跳转过去需要新增编辑的实体名）, Title: `编辑不良代码组：${params['record']['DFTG_CODE']}`（定义tab页签的标题）, pCode: 'DFTG_CODE'（主表的关键字段代码） }
 *     替换主页面新增按钮方法同上
 *  3. 在菜单管理新建一个高级页面。
 *  4. 配置高级页面，定义表单列 getFormSchema
 *  5. 初始化表格 GetBasicColumnAndInit
 *  6. 设置返回 getHomeUrl
 *  7. 设置标题 getTitle
 *  8. 设置新增时就默认的值 getOthersValues
 *  9. 替换删除方法 GetActionsData
 * @param {*} params
 * @param {array} args
 * @return {*}
 */
export function GetActionsData(params: {}, ...args) {
  let data = [] as ActionItem[];
  return data;
}

export function GetUseModalData(type: string) {
  let data = {};
  switch (type) {
    case 'BAS_DEFECT_GRP':
      data = {
        add: useModal(),
        set: useModal(),
        addRot: useModal(),
        setRot: useModal(),
      };
      break;
  }
  return data;
}

/**
 * @description: Select 自定义onChange方法
 * @param {any} e
 * @param {string} fnName
 * @param {string} entityName
 * @return {*}
 */
export function custOnChange(e: any, fnName: string, entityName: string) {
  if (!isNullOrEmpty(fnName)) {
    switch (entityName) {
      case 'BAS_REASON':
        // onChangeFns[fnName](e);
        break;
      default:
        break;
        (e) => {};
    }
  } else {
    (e) => {};
  }
}

/**
 * @description: 打开自定义弹出框方法
 * @return {*}
 */
export function OpenCustModal(
  openItemModal: Fn,
  entityName: string,
  slotName: string,
  others: Fn[],
  ...args
) {
  switch (entityName) {
    case 'BIZ_MES_WO':
    case 'BIZ_MES_WO_Config': //根据带入的名称打开不同的实体列表
      woCustFn(openItemModal, slotName, others, args);
      break;
    default: //默认打开物料列表
      openItemModal(true, {
        title: '物料列表',
        schemas: [
          {
            field: 'ITEM_CODE',
            component: 'Input',
            label: '物料编码',
            colProps: {
              span: 12,
            },
          },
        ],
        ItemColumns: [
          {
            title: t('物料编码'),
            dataIndex: 'ITEM_CODE',
            resizable: true,
            sorter: true,
            width: 200,
          },
          {
            title: t('物料名称'),
            dataIndex: 'ITEM_NAME',
            resizable: true,
            sorter: true,
            width: 180,
          },
        ],
        tableName: 'BAS_ITEM',
        rowKey: 'ITEM_CODE',
        searchInfo: { TABLE_NAME: 'BAS_ITEM' },
      });
      break;
  }
}

/**
 * @description: 获取自定义弹出框中表单的结构
 * @param {string} type
 * @return {*}
 */
export function getFormSchema(type: string) {
  let _formSchema = [] as FormSchema[];
  switch (type) {
    case 'BIZ_MES_WO':
      _formSchema = woformSchema;
      break;
    default:
      break;
  }
  return _formSchema;
}
